$ErrorActionPreference  = 'Stop';

# Make sure to kill any presencelight processes before attempting an
# installation. This covers the case that PresenceLight is currently
# installed outside of Chocolatey
Get-Process presencelight* -ErrorAction SilentlyContinue | Stop-Process

$WindowsVersion=[Environment]::OSVersion.Version
if ($WindowsVersion.Major -ne "10") {
  throw "This package requires Windows 10."
}

$IsCorrectBuild=[Environment]::OSVersion.Version.Build
if ($IsCorrectBuild -lt "17134") {
  throw "This package requires at least Windows 10 version build 17134.x."
}

$packageName    = "presencelight"
$toolsDir       = "$(Split-Path -parent $MyInvocation.MyCommand.Definition)"
$InstallDir     = Join-Path $env:APPDATA 'PresenceLight'

$pp = Get-PackageParameters

if($pp['InstallDir']){
  $InstallDir = $pp['InstallDir']
}

$packageArgs = @{
  packageName    = $packageName
  unzipLocation  = $InstallDir
  urlARM         = "https://github.com/isaacrlevin/presencelight/releases/download/Desktop-v5.5.18/PresenceLight.5.5.18-win-arm64.zip"
  url86bit       = "https://github.com/isaacrlevin/presencelight/releases/download/Desktop-v5.5.18/PresenceLight.5.5.18-x86.zip"
  url64bit       = "https://github.com/isaacrlevin/presencelight/releases/download/Desktop-v5.5.18/PresenceLight.5.5.18-x64.zip"
  checksumARM    = "CC056368011081BA8D23C42EC218E3169AA3D0F6E7073E022FA1259087242061"
  checksum       = "BFB62A9871CB14A079CE159AC0F7D2BA5DF3458C89776244E83C0BF41C7AE8E3"
  checksum64     = "23713B5561502BFD5A763B13081302BC306392DF85FBD24B74490476A84865B6"
  checksumType   = 'SHA256'
}

Install-ChocolateyZipPackage @packageArgs

$exePath = Join-Path $InstallDir 'PresenceLight.exe'


Write-Output "Adding shortcut to Start Menu"
Install-ChocolateyShortcut -ShortcutFilePath "C:\ProgramData\Microsoft\Windows\Start Menu\Programs\PresenceLight.lnk" -TargetPath $exePath -WorkingDirectory $InstallDir

Write-Output "Adding shortcut to Startup"
Install-ChocolateyShortcut -ShortcutFilePath "C:\ProgramData\Microsoft\Windows\Start Menu\Programs\Startup\PresenceLight.lnk" -TargetPath $exePath -WorkingDirectory $InstallDir

